View Source OpenPGP.UserIdPacket (OpenPGP v0.6.4)
Represents structured data for User ID Packet (Tag 13).
Example:
iex> OpenPGP.UserIdPacket.decode("Alice <alice@example.com>")
{%OpenPGP.UserIdPacket{id: "Alice <alice@example.com>"}, <<>>}RFC4880
5.11. User ID Packet (Tag 13)
A User ID packet consists of UTF-8 text that is intended to represent the name and email address of the key holder. By convention, it includes an RFC 2822 mail name-addr, but there are no restrictions on its content. The packet length in the header specifies the length of the User ID.
Summary
Functions
Decode User ID Packet given input binary. Return structured packet and remaining binary (empty binary).
Types
@type t() :: %OpenPGP.UserIdPacket{id: binary()}
Functions
Decode User ID Packet given input binary. Return structured packet and remaining binary (empty binary).